#!/usr/bin/python3

import sys
from sys import argv

SUCCESS = 0
FAILURE = 1
ERROR = 2

NEWLINE = b'\n'

def parse_arguments(arguments):
    if len(arguments) != 3:
        print(f"usage: {arguments[0]} {{file1}} {{file2}}", sys.stderr)
        exit(ERROR)

    ret = None
    try:
        ret = [
                open(arguments[1], "rb") if arguments[1] != '-'
                                         else sys.stdin,
                arguments[1],
                open(arguments[2], "rb") if arguments[2] != '-'
                                         else sys.stdin,
                arguments[2],
              ]
    except Exception as e:
        print(e, file=sys.stderr)
        exit(ERROR)

    return ret


def parse_files(fd1, fname1, fd2, fname2):
    bytecounter = 0
    linecounter = 1
    with fd2:
        with fd1:
            byte1 = bytes(fd1.read(1))
            byte2 = bytes(fd2.read(1))
            print(byte1, byte2)
            while byte1 != b'' and byte2 != b'':
                bytecounter += 1
                if byte1 == NEWLINE:
                    linecounter += 1

                if byte1 == byte2:
                    byte1 = fd1.read(1)
                    byte2 = fd2.read(1)
                else:
                    print(f"{fname1} {fname2} differ: byte {bytecounter}, line {linecounter}")
                    return FAILURE
            if byte1 != b'':
                print(f"{argv[0]}: EOF on {fname1} after byte {bytecounter}", file=sys.stderr)
            if byte2 != b'':
                print(f"{argv[0]}: EOF on {fname2} after byte {bytecounter}", file=sys.stderr)
    return SUCCESS

def main():
    return parse_files(*parse_arguments(argv))

if __name__ == "__main__":
    exit(main())
