#!/usr/bin/python3

import _io
import sys
from sys import argv

SUCCESS = 0
FAILURE = 1
ERROR = 2

NEWLINE = b'\n'

def parse_arguments(arguments):
    if len(arguments) != 3:
        print(f"usage: {arguments[0]} {{file1}} {{file2}}", file=sys.stderr)
        exit(ERROR)

    fname1 = arguments[1]
    fname2 = arguments[2]

    if fname1 == fname2:
        # if filenames are equal, check whether we can open the file
        try:
            # no need trying to open standard input
            if fname1 != '-':
                open(fname1, "rb") 
            # filenames equal and open succeeded => file contents are equal
            exit(SUCCESS)
        except Exception as e:
            # opening failed, show error
            print(e, file=sys.stderr)
            exit(ERROR)

    ret = None
    try:
        ret = [
                open(fname1, "rb") if fname1 != '-'
                                         else sys.stdin.buffer,
                fname1,
                open(fname2, "rb") if fname2 != '-'
                                         else sys.stdin.buffer,
                fname2,
              ]
    except Exception as e:
        print(e, file=sys.stderr)
        exit(ERROR)

    if ret[0] == sys.stdin.buffer and ret[2] == sys.stdin.buffer:
        print("only one standard input allowed", file=sys.stderr)
        exit(ERROR)

    return ret


def parse_files(fd1: _io.BufferedReader,
        fname1: str,
        fd2: _io.BufferedReader,
        fname2: str):
    bytecounter = 0
    linecounter = 1
    with fd2:
        with fd1:
            byte1 = bytes(fd1.read(1))
            byte2 = bytes(fd2.read(1))
            while byte1 != b'' and byte2 != b'':
                bytecounter += 1
                if byte1 == NEWLINE:
                    linecounter += 1

                if byte1 == byte2:
                    byte1 = fd1.read(1)
                    byte2 = fd2.read(1)
                else:
                    print(f"{fname1} {fname2} differ: byte {bytecounter}, line {linecounter}")
                    return FAILURE
            if byte1 != b'':
                print(f"{argv[0]}: EOF on {fname2} after byte {bytecounter}", file=sys.stderr)
            if byte2 != b'':
                print(f"{argv[0]}: EOF on {fname1} after byte {bytecounter}", file=sys.stderr)
    return SUCCESS

def main():
    return parse_files(*parse_arguments(argv))

if __name__ == "__main__":
    exit(main())
